@@ -1,9 +1,10 @@
 use strict;
 use warnings;
 use File::Spec;
-use ExtUtils::Typemap;
+use inc::latest 'ExtUtils::Typemap';
 
 my $xsp_dir = 'ROOT_XSP';
+my $xsp_dir_compile = File::Spec->catdir(File::Spec->updir, 'ROOT_XSP');
 
 opendir my $dh, $xsp_dir or die $!;
 open my $oh_xs, '>', 'rootclasses.xsinclude' or die $!;
@@ -14,10 +15,10 @@ my $typemap = ExtUtils::Typemap->new(file => 'rootclasses.map');
 while(defined(my $file = readdir($dh))) {
   next if $file !~ /^(.+)\.xsp$/i;
   my $basename = $1;
-  my $full = File::Spec->catfile($xsp_dir, $file);
+  my $full = File::Spec->catfile($xsp_dir_compile, $file);
   print $oh_xs <<ENDXSCODE;
 
-INCLUDE_COMMAND: \$^X -MExtUtils::XSpp::Cmd -e xspp -- -t typemap.xsp $full
+INCLUDE_COMMAND: \$^X -MExtUtils::XSpp::Cmd -e xspp -- -t ../typemap.xsp $full
 
 ENDXSCODE
   print $oh_h <<ENDHCODE;
