@@ -1,6 +1,8 @@
 use strict;
 use warnings;
 use SOOT ':all';
+use threads;
+use Time::HiRes 'usleep';
 
 my $sw = TStopwatch->new(); 
 $sw->Start();
@@ -22,17 +24,24 @@ $ht->SetMaximum($signal);
 $ht->SetMinimum(-$signal);
 $ht->SetStats(0);
 $ht->SetLineColor(2);
-$ht->GetXaxis()->SetTimeDisplay(1); # FIXME the dreaded "enum" for GetXaxis
+$ht->GetXaxis()->SetTimeDisplay(1);
 $ht->GetYaxis()->SetNdivisions(520);
 $ht->Draw();
    
+my $thr = threads->new(sub {$gApplication->Run()}); #canvas can be edited during the loop
+usleep(5000); # FIXME find better way to fix this
+$gApplication->SetReturnFromRun(1);
+
 for my $i (1..2299) {
   #======= Build a signal : noisy damped sine ======
   my $noise = $gRandom->Gaus(0,120);
-  $noise += $signal*sin(($i-700.)*6.28/30)*exp((700.-$i)/300.) if ($i > 700) ;
-  $ht->SetBinContent($i,1.0*$noise);
+  $noise += $signal*sin(($i-700.)*6.28/30)*exp((700.-$i)/300.) if $i > 700;
+  $ht->SetBinContent($i,$noise);
   $c1->Modified();
   $c1->Update();
-  $gSystem->ProcessEvents(); #canvas can be edited during the loop
 }
 print sprintf("Real Time = %8.3fs, Cpu Time = %8.3fs\n",$sw->RealTime(),$sw->CpuTime());
+
+$gApplication->Terminate();
+$thr->join();
+
