@@ -1,10 +1,12 @@
 # this module will be loaded by ExtUtils/XSpp/Grammar.pm and needs to
 # define subroutines in the ExtUtils::XSpp::Grammar namespace
-package ExtUtils::XSpp::Grammar;
-
+package ExtUtils::XSpp::Lexer;
+# for the indexer and friends
 use strict;
 use warnings;
 
+package ExtUtils::XSpp::Grammar;
+
 use ExtUtils::XSpp::Node;
 use ExtUtils::XSpp::Node::Access;
 use ExtUtils::XSpp::Node::Argument;
@@ -19,10 +21,16 @@ use ExtUtils::XSpp::Node::Module;
 use ExtUtils::XSpp::Node::Package;
 use ExtUtils::XSpp::Node::Raw;
 use ExtUtils::XSpp::Node::Type;
+use ExtUtils::XSpp::Node::PercAny;
+use ExtUtils::XSpp::Node::Enum;
+use ExtUtils::XSpp::Node::EnumValue;
+use ExtUtils::XSpp::Node::Preprocessor;
 
 use ExtUtils::XSpp::Typemap;
 use ExtUtils::XSpp::Exception;
 
+use Digest::MD5 qw(md5_hex);
+
 my %tokens = ( '::' => 'DCOLON',
                ':'  => 'COLON',
                '%{' => 'OPSPECIAL',
@@ -37,6 +45,7 @@ my %tokens = ( '::' => 'DCOLON',
                 '~' => 'TILDE',
                 '*' => 'STAR',
                 '&' => 'AMP',
+                '|' => 'PIPE',
                 ',' => 'COMMA',
                 '=' => 'EQUAL',
                 '/' => 'SLASH',
@@ -60,20 +69,21 @@ my %tokens = ( '::' => 'DCOLON',
                '%include'    => 'p_include',
              );
 
-my %keywords = ( const => 1,
-                 class => 1,
-                 unsigned => 1,
-                 short => 1,
-                 long => 1,
-                 int => 1,
-                 char => 1,
-                 package_static => 1,
-                 class_static => 1,
-                 static => 1,
-                 public => 1,
-                 private => 1,
-                 protected => 1,
-                 virtual => 1,
+my %keywords = ( const           => 1,
+                 class           => 1,
+                 unsigned        => 1,
+                 short           => 1,
+                 long            => 1,
+                 int             => 1,
+                 char            => 1,
+                 package_static  => 1,
+                 class_static    => 1,
+                 static          => 1,
+                 public          => 1,
+                 private         => 1,
+                 protected       => 1,
+                 virtual         => 1,
+                 enum            => 1,
                  );
 
 sub get_lex_mode { return $_[0]->YYData->{LEX}{MODES}[0] || '' }
@@ -114,6 +124,32 @@ sub read_more {
   return $buf;
 }
 
+# for tests
+sub _random_digits { sprintf '%06d', rand 100000 }
+
+sub push_conditional {
+  my $p = $_[0];
+  my $file = $p->YYData->{LEX}{FILE} ?
+                 substr md5_hex( $p->YYData->{LEX}{FILE} ), 0, 8 :
+                 'zzzzzzzz';
+  my $rand = _random_digits;
+
+  my $symbol = 'XSpp_' . $file . '_' . $rand;
+  push @{$p->YYData->{LEX}{CONDITIONAL}}, $symbol;
+
+  return $symbol;
+}
+
+sub pop_conditional {
+  pop @{$_[0]->YYData->{LEX}{CONDITIONAL}};
+}
+
+sub get_conditional {
+  return undef unless $_[0]->YYData->{LEX}{CONDITIONAL};
+  return undef unless @{$_[0]->YYData->{LEX}{CONDITIONAL}};
+  return $_[0]->YYData->{LEX}{CONDITIONAL}[-1];
+}
+
 sub yylex {
   my $data = $_[0]->YYData->{LEX};
   my $buf = $data->{BUFFER};
@@ -140,7 +176,9 @@ sub yylex {
       $$buf =~ s/^[\s\n\r]+//;
       next unless length $$buf;
 
-      if( $$buf =~ s/^([+-]?(?=\d|\.\d)\d*(?:\.\d*)?(?:[Ee](?:[+-]?\d+))?)// ) {
+      if( $$buf =~ s/^([+-]?0x[0-9a-fA-F]+)// ) {
+        return ( 'INTEGER', $1 );
+      } elsif( $$buf =~ s/^([+-]?(?=\d|\.\d)\d*(?:\.\d*)?(?:[Ee](?:[+-]?\d+))?)// ) {
         my $v = $1;
         return ( 'INTEGER', $v ) if $v =~ /^[+-]?\d+$/;
         return ( 'FLOAT', $v );
@@ -156,13 +194,12 @@ sub yylex {
           $$buf =~ s/(?:\r\n|\r|\n)$//;
           push @rows, $$buf;
         }
+      } elsif( $$buf =~ s/^(\%\w+)// ) {
+        return ( $tokens{$1}, $1 ) if exists $tokens{$1};
+        return ( 'p_any', substr $1, 1 );
       } elsif( $$buf =~ s/^( \%}
                       | \%{ | {\%
-                      | \%name | \%typemap | \%module  | \%code
-                      | \%file | \%cleanup | \%package | \%length
-                      | \%loadplugin | \%include | \%postcall
-                      | \%exception | \%catch
-                      | [{}();%~*&,=\/\.\-<>]
+                      | [{}();%~*&,=\/\.\-<>|]
                       | :: | :
                        )//x ) {
         return ( $tokens{$1}, $1 );
@@ -174,6 +211,16 @@ sub yylex {
         return ( 'ID', $1 );
       } elsif( $$buf =~ s/^("[^"]*")// ) {
         return ( 'QUOTED_STRING', $1 );
+      } elsif( $$buf =~ s/^(#\s*(if|ifdef|ifndef|else|elif|endif)\b.*)(?:\r\n|\r|\n)// ) {
+        my $symbol;
+        if( $2 eq 'else' || $2 eq 'elif' || $2 eq 'endif' ) {
+          pop_conditional( $_[0] );
+        }
+        if( $2 ne 'endif' ) {
+          $symbol = push_conditional( $_[0] );
+        }
+
+        return ( 'PREPROCESSOR', [ $1, $symbol ] );
       } elsif( $$buf =~ s/^(#.*)(?:\r\n|\r|\n)// ) {
         return ( 'RAW_CODE', $1 );
       } else {
@@ -221,6 +268,17 @@ sub add_data_comment {
   ExtUtils::XSpp::Node::Comment->new( rows => $rows );
 }
 
+sub add_top_level_directive {
+  my( $parser, %args ) = @_;
+
+  $parser->YYData->{PARSER}->handle_toplevel_tag_plugins
+    ( $args{any},
+      any_named_arguments      => $args{any_named_arguments},
+      any_positional_arguments => $args{any_positional_arguments},
+      condition                => $parser->get_conditional,
+      );
+}
+
 sub make_argument {
   my( $p, $type, $name, $default ) = @_;
 
@@ -230,31 +288,32 @@ sub make_argument {
 }
 
 sub create_class {
-  my( $parser, $name, $bases, $metadata, $methods ) = @_;
-  my %metadata = @$metadata;
-  _merge_keys('catch', \%metadata, $metadata);
+  my( $parser, $name, $bases, $metadata, $methods, $condition ) = @_;
+  my %args = @$metadata;
+  _merge_keys( 'catch', \%args, $metadata );
 
-  my $class = ExtUtils::XSpp::Node::Class->new( %metadata, # <-- catch only for now
+  my $class = ExtUtils::XSpp::Node::Class->new( %args, # <-- catch only for now
                                                 cpp_name     => $name,
-                                                base_classes => $bases );
+                                                base_classes => $bases,
+                                                condition    => $condition,
+                                                );
 
   # when adding a class C, automatically add weak typemaps for C* and C&
-  my $ptr = ExtUtils::XSpp::Node::Type->new
-                ( base    => $name,
-                  pointer => 1,
-                  );
-  my $ref = ExtUtils::XSpp::Node::Type->new
-                ( base      => $name,
-                  reference => 1,
-                  );
+  ExtUtils::XSpp::Typemap::add_class_default_typemaps( $name );
 
-  ExtUtils::XSpp::Typemap::add_weak_typemap_for_type
-      ( $ptr, ExtUtils::XSpp::Typemap::simple->new( type => $ptr ) );
-  ExtUtils::XSpp::Typemap::add_weak_typemap_for_type
-      ( $ref, ExtUtils::XSpp::Typemap::reference->new( type => $ref ) );
+  my @any  = grep  $_->isa( 'ExtUtils::XSpp::Node::PercAny' ), @$methods;
+  my @rest = grep !$_->isa( 'ExtUtils::XSpp::Node::PercAny' ), @$methods;
+
+  foreach my $any ( @any ) {
+    $parser->YYData->{PARSER}->handle_class_tag_plugins
+      ( $class, $any->{NAME},
+        any_named_arguments      => $any->{NAMED_ARGUMENTS},
+        any_positional_arguments => $any->{POSITIONAL_ARGUMENTS},
+        );
+  }
 
   # finish creating the class
-  $class->add_methods( @$methods );
+  $class->add_methods( @rest );
 
   return $class;
 }
@@ -276,68 +335,112 @@ sub _merge_keys {
 }
 
 sub add_data_function {
-  my $parser = shift @_;
-  my %args   = @_;
-  _merge_keys('catch', \%args, \@_);
+  my( $parser, @args ) = @_;
+  my %args   = @args;
+  _merge_keys( 'catch', \%args, \@args );
 
-  ExtUtils::XSpp::Node::Function->new
-      ( cpp_name  => $args{name},
-        perl_name => $args{perl_name},
-        class     => $args{class},
-        ret_type  => $args{ret_type},
-        arguments => $args{arguments},
-        code      => $args{code},
-        cleanup   => $args{cleanup},
-        postcall  => $args{postcall},
-        catch     => $args{catch},
+  my $f = ExtUtils::XSpp::Node::Function->new
+              ( cpp_name  => $args{name},
+                perl_name => $args{perl_name},
+                class     => $args{class},
+                ret_type  => $args{ret_type},
+                arguments => $args{arguments},
+                code      => $args{code},
+                cleanup   => $args{cleanup},
+                postcall  => $args{postcall},
+                catch     => $args{catch},
+                condition => $args{condition},
+                );
+
+  if( $args{any} ) {
+    $parser->YYData->{PARSER}->handle_function_tag_plugins
+      ( $f, $args{any},
+        any_named_arguments      => $args{any_named_arguments},
+        any_positional_arguments => $args{any_positional_arguments},
         );
+  }
+
+  return $f;
 }
 
 sub add_data_method {
-  my $parser = shift @_;
-  my %args   = @_;
-  _merge_keys('catch', \%args, \@_);
+  my( $parser, @args ) = @_;
+  my %args   = @args;
+  _merge_keys( 'catch', \%args, \@args );
 
-  ExtUtils::XSpp::Node::Method->new
-      ( cpp_name  => $args{name},
-        ret_type  => $args{ret_type},
-        arguments => $args{arguments},
-        const     => $args{const},
-        code      => $args{code},
-        cleanup   => $args{cleanup},
-        postcall  => $args{postcall},
-        perl_name => $args{perl_name},
-        catch     => $args{catch},
+  my $m = ExtUtils::XSpp::Node::Method->new
+            ( cpp_name  => $args{name},
+              ret_type  => $args{ret_type},
+              arguments => $args{arguments},
+              const     => $args{const},
+              code      => $args{code},
+              cleanup   => $args{cleanup},
+              postcall  => $args{postcall},
+              perl_name => $args{perl_name},
+              catch     => $args{catch},
+              condition => $args{condition},
+              );
+
+  if( $args{any} ) {
+    $parser->YYData->{PARSER}->handle_method_tag_plugins
+      ( $m, $args{any},
+        any_named_arguments      => $args{any_named_arguments},
+        any_positional_arguments => $args{any_positional_arguments},
         );
+  }
+
+  return $m;
 }
 
 sub add_data_ctor {
-  my $parser = shift @_;
-  my %args   = @_;
-  _merge_keys('catch', \%args, \@_);
+  my( $parser, @args ) = @_;
+  my %args   = @args;
+  _merge_keys( 'catch', \%args, \@args );
 
-  ExtUtils::XSpp::Node::Constructor->new
-      ( cpp_name  => $args{name},
-        arguments => $args{arguments},
-        code      => $args{code},
-        cleanup   => $args{cleanup},
-        postcall  => $args{postcall},
-        catch     => $args{catch},
+  my $m = ExtUtils::XSpp::Node::Constructor->new
+            ( cpp_name  => $args{name},
+              arguments => $args{arguments},
+              code      => $args{code},
+              cleanup   => $args{cleanup},
+              postcall  => $args{postcall},
+              catch     => $args{catch},
+              condition => $args{condition},
+              );
+
+  if( $args{any} ) {
+    $parser->YYData->{PARSER}->handle_method_tag_plugins
+      ( $m, $args{any},
+        any_named_arguments      => $args{any_named_arguments},
+        any_positional_arguments => $args{any_positional_arguments},
         );
+  }
+
+  return $m;
 }
 
 sub add_data_dtor {
-  my $parser = shift @_;
-  my %args   = @_;
-  _merge_keys('catch', \%args, \@_);
+  my( $parser, @args ) = @_;
+  my %args   = @args;
+  _merge_keys( 'catch', \%args, \@args );
 
-  ExtUtils::XSpp::Node::Destructor->new
-      ( cpp_name  => $args{name},
-        code      => $args{code},
-        cleanup   => $args{cleanup},
-        postcall  => $args{postcall},
-        catch     => $args{catch},
+  my $m = ExtUtils::XSpp::Node::Destructor->new
+            ( cpp_name  => $args{name},
+              code      => $args{code},
+              cleanup   => $args{cleanup},
+              postcall  => $args{postcall},
+              catch     => $args{catch},
+              condition => $args{condition},
+              );
+
+  if( $args{any} ) {
+    $parser->YYData->{PARSER}->handle_method_tag_plugins
+      ( $m, $args{any},
+        any_named_arguments      => $args{any_named_arguments},
+        any_positional_arguments => $args{any_positional_arguments},
         );
+  }
+
+  return $m;
 }
 
 sub is_directive {
