@@ -1,5 +1,6 @@
 
 #include "ClassIterator.h"
+#include "SOOTDebug.h"
 
 namespace SOOT {
   static TPRegexp gBadClassRegexp("T(?:Btree|List|Map|ObjArray|OrdCollection|RefArray)Iter"); // FIXME "Warning in <TClass::TClass>: no dictionary for class iterator<bidirectional_iterator_tag,TObject*,long,const TObject**,const TObject*&> is available"
@@ -10,7 +11,7 @@ namespace SOOT {
   const char*
   ClassIterator::next()
   {
-    if (fClassNo < gClassTable->Classes()) {
+    if ((int)fClassNo < gClassTable->Classes()) {
       const char* name = gClassTable->At(fClassNo++);
       TString cn(name);
       if (cn.Contains("<") || cn.Contains("::") || gBadClassRegexp.MatchB(cn)) // FIXME optimize
