@@ -49,8 +49,9 @@ namespace SOOT {
    *  and possibly also frees the underlying ROOT object if it's the last
    *  reference.
    *  If "mustNotClearRefPad" is set, the containing PtrAnnotation isn't freed.
+   *  Returns whether or not the underlying ROOT object was freed.
    */
-  void UnregisterObject(pTHX_ SV* thePerlObject, bool mustNotClearRefPad = false);
+  bool UnregisterObject(pTHX_ SV* thePerlObject, bool mustNotClearRefPad = false);
 
   /** Given a Perl object (SV*) that's known to be one of our mock TObject like
    *  creatures, fetch the class name and the ROOT object.
